@@ -63,7 +63,7 @@ class HamiltonianResultsContainer(OrderedDict):
                        upgraded to the HamiltonianResultsContainer class
 
             data_dir -  the directory in which the file is to be saved or loaded
-                        from, defults to the config.root_dir
+                        from, defaults to the config.root_dir
         """
 
         super().__init__()
@@ -129,7 +129,7 @@ class HamiltonianResultsContainer(OrderedDict):
         for key, val in add_dic.items():
             # TODO remove all copies of same data
             #  if key in self.keys():
-                #raise ValueError('trying to overwrite an exsiting varation')
+                #raise ValueError('trying to overwrite an existing variation')
             self[str(int(key)+Init_number_of_keys)] = val
         return 1
 
@@ -141,7 +141,7 @@ class HamiltonianResultsContainer(OrderedDict):
             z {pd.DataFrame} -- Input
 
         Returns:
-            Sorted DtaaFrame
+            Sorted DataFrame
         """
         if isinstance(z, pd.DataFrame):
             return z.sort_index(axis=1)
@@ -241,7 +241,7 @@ class QuantumAnalysis(object):
         results = DistributedAnalysis.results_variations_on_inside(
             self.data.results)
 
-        # Convinience functions
+        # Convenience functions
         self.variations = variations or list(self.data.results.keys())
         self._hfss_variables = results['hfss_variables']
         self.freqs_hfss = results['freqs_hfss_GHz']
@@ -251,7 +251,7 @@ class QuantumAnalysis(object):
         self.Cjs = results['Cjs']  # DataFrame
         self.OM = results['Om']  # dict of dataframes
         self.PM = results['Pm']  # participation matrices - raw, unnormed here
-        # participation matrices for capactive elements
+        # participation matrices for capacitive elements
         self.PM_cap = results['Pm_cap']
         self.SM = results['Sm']  # sign matrices
         self.I_peak = results['I_peak']
@@ -294,7 +294,7 @@ class QuantumAnalysis(object):
 
     def get_vs_variable(self, swp_var, attr: str):
         """
-        Convert the index of a dicitoanry that is stored here from
+        Convert the index of a dictionary that is stored here from
         variation number to variable value.
 
         Args:
@@ -308,10 +308,10 @@ class QuantumAnalysis(object):
 
     def get_variable_vs(self, swpvar, lv=None):
         """ lv is list of variations (example ['0', '1']), if None it takes all variations
-            swpvar is the variable by which to orginize
+            swpvar is the variable by which to organize
 
             return:
-            ordered dicitonary of key which is the variation number and the magnitude
+            ordered dictionary of key which is the variation number and the magnitude
             of swaver as the item
         """
         ret = OrderedDict()
@@ -337,7 +337,7 @@ class QuantumAnalysis(object):
             has a specific value lv is list of variations (example ['0', '1']),
             if None it takes all variations
             swpvar is a string and the name of the variable we wish to filter
-            value is the value of swapvr in which we are intrested
+            value is the value of swapvr in which we are interested
 
             returns lv - a list of the variations for which swavr==value
             """
@@ -431,7 +431,7 @@ class QuantumAnalysis(object):
 
     def get_Ecs(self, variation):
         ''' ECs in GHz
-        Returns as padnas series
+        Returns as pandas series
         '''
         Cs = self.Cjs[variation]
         return Convert.Ec_from_Cs(Cs,  units_in='F', units_out='GHz')
@@ -497,7 +497,7 @@ class QuantumAnalysis(object):
             #s = self.sols[variation]
             # sum of participation energies as calculated by global UH and UE
             # U_mode = s['U_E'] # peak mode energy; or U bar as i denote it sometimes
-            # We need to add the capactiro here, and maybe take the mean of that
+            # We need to add the capacitor here, and maybe take the mean of that
 
             energies = self._get_ansys_total_energies(variation)
 
@@ -525,7 +525,7 @@ class QuantumAnalysis(object):
                 idx_cap = Pm_cap > 0.15
             else:
                 raise NotImplementedError(
-                    "Unkown _renorm_pj argument or config values!")
+                    "Unknown _renorm_pj argument or config values!")
 
             if print_:
                 # \nPm_cap_norm=\n{Pm_cap_norm}")
@@ -560,10 +560,10 @@ class QuantumAnalysis(object):
 
     def get_epr_base_matrices(self, variation, _renorm_pj=None, print_=False):
         r'''
-        Return the key matricies used in the EPR method for analytic calcualtions.
+        Return the key matrices used in the EPR method for analytic calculations.
 
         All as matrices
-            :PJ: Participatuion matrix, p_mj
+            :PJ: Participation matrix, p_mj
             :SJ: Sign matrix, s_mj
             :Om: Omega_mm matrix (in GHz) (\hbar = 1) Not radians.
             :EJ: E_jj matrix of Josephson energies (in same units as hbar omega matrix)
@@ -573,7 +573,7 @@ class QuantumAnalysis(object):
             Return all as *np.array*
                 PM, SIGN, Om, EJ, Phi_ZPF
         '''
-        # TODO: superseed by Convert.ZPF_from_EPR
+        # TODO: supersede by Convert.ZPF_from_EPR
 
         res = self._get_participation_normalized(
             variation, _renorm_pj=_renorm_pj, print_=print_)
@@ -730,7 +730,7 @@ class QuantumAnalysis(object):
             self.print_variation(variation)
             self.print_result(result)
     
-        self.n_modes = tmp_n_modes # TODO is this smart should consider defining the modes of intrest in the initilazaition of the quantum object
+        self.n_modes = tmp_n_modes # TODO is this smart should consider defining the modes of interest in the initialisation of the quantum object
         self.modes[variation]=tmp_modes 
         return result
 
@@ -812,7 +812,7 @@ class QuantumAnalysis(object):
             dic['x_label'] = var_name
             dic['x'] = self.get_variable_value(var_name, lv=lv)
         else:
-            raise ValueError('more than one hfss variablae changes each time')
+            raise ValueError('more than one hfss variable changes each time')
 
         return lv, dic
 
@@ -1023,11 +1023,11 @@ class QuantumAnalysis(object):
                            _normed=True):
         """
 
-            inductive (bool): EPR forjunciton inductance when True, else for capactiors
+            inductive (bool): EPR for junction inductance when True, else for capacitors
 
         Returns:
         ----------------
-        Returns a multindex dataframe:
+        Returns a multiindex dataframe:
             index 0: sweep variable
             index 1: mode number
             column: junction number
@@ -1177,7 +1177,7 @@ class QuantumAnalysis(object):
 
     def quick_plot_convergence(self, ax = None):
         """
-        Plot a report of the Ansys converngece vs pass number ona twin axis
+        Plot a report of the Ansys convergence vs pass number ona twin axis
         for the number of tets and the max delta frequency of the eignemode.
         """
         ax = ax or plt.gca()
@@ -1193,7 +1193,7 @@ class QuantumAnalysis(object):
 
 
 def extract_dic(name=None, file_name=None):
-    """#name is the name of the dictionry as saved in the npz file if it is None,
+    """#name is the name of the dictionary as saved in the npz file if it is None,
     the function will return a list of all dictionaries in the npz file
     file name is the name of the npz file"""
     with np.load(file_name, allow_pickle=True) as f:
